/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef CONFIG_H_
#define CONFIG_H_

#include <app.h>

#define EDJ_CREATEVIEW "edje/create-view.edj"
#define EDJ_NAME "edje/scheduler.edj"

static inline const char * GET_PATH(const char * file_path)
{
    static char layout_edj_path[PATH_MAX] = {'\0'};

    char *res_path_buff = app_get_resource_path();
    snprintf(layout_edj_path, PATH_MAX, "%s%s", res_path_buff, file_path);
    free(res_path_buff);

    return layout_edj_path;
}

#define _HOUR (60)
#define _DAY (60 * 24)
#define _WEEK (60 * 24 * 7)

#define MORE_POPUP_X_OFFSET                 50
#define KEY_PRIORITY_DATA                   "KEY_PRIORITY_DATA"
#define WARNING_POPUP_TEXT                  "<align=center>Please enter title</align>"
#define WARNING_TIME_POPUP_TEXT             "<align=center>Invalid period selected</align>"
#define WARNING_REPEAT_UNTIL_POPUP_TEXT     "<align=center>Please select repeat until range</align>"


#define MAX_REMINDER_NUMBERS          6
#define STRING_SIZE                   64
#define TIME_STR_LEN                  32
#define DAYS_IN_WEEK                  7
#define SUBJECT_CHAR_LIMIT            100
#define SUBJECT_BYTE_LIMIT            256
#define CALENDAR_BUTTON_WIDTH         250
#define BUTTON_SCALE_WIDTH            220
#define BUTTON_SCALE_CALENDAR_WIDTH   300
#define BUTTON_SCALE_DATETIME_WIDTH   175
#define BUTTON_SCALE_HEIGHT           36

//See tm structure documentation.
#define TM_START_YEAR 1900
#define TM_START_MONTH 1

#define DATE_TIME_BUF_LEN 256

#define REMINDER_NUMBERS_LIMIT 5
#define BOX_PADDING 20

enum _ENTRY_TYPE
{
    TITLE_ENTRY,
    LOCATION_ENTRY,
    DESCRIPTION_ENTRY
};

typedef enum _ENTRY_TYPE ENTRY_TYPE;

enum _EVENT_PARAM_TYPE
{
    PARAM_REMINDER = 0,
    PARAM_PRIORITY = 1,
    PARAM_SENSITIVITY = 2,
    PARAM_STATUS = 3
};

typedef enum _EVENT_PARAM_TYPE EVENT_PARAM_TYPE;

#endif /* CONFIG_H_ */

